@@ -4,8 +4,8 @@ use strict;
 use warnings;
 use v5.16;
 use base 'TAP::Formatter::File';
-use Data::Dumper;
-our $VERSION = '0.3.0_8';
+
+our $VERSION = '0.3.1';
 
 use TAP::Formatter::GitHubActions::Error;
 use TAP::Formatter::GitHubActions::ErrorGroup;
@@ -14,6 +14,7 @@ use TAP::Formatter::GitHubActions::ErrorAggregate;
 
 my $MONOPHASIC_REGEX = qr/^Failed\stest .+\nat/;
 my $RUNNING_IN_GHA = $ENV{GITHUB_ACTIONS};
+my $GHA_SKIP_SUMMARY = $ENV{GHA_SKIP_SUMMARY};
 
 sub _stash_line_for_current_test {
   my ($self, $parser, $line) = @_;
@@ -124,7 +125,7 @@ sub _output_report_notice {
     )
   };
 
-  if (!$ENV{TAP_WITHIN_TAP} && !!@workflow_vars) {
+  if (!$GHA_SKIP_SUMMARY && !!@workflow_vars) {
     $workflow_url = sprintf("%s/%s/actions/runs/%s", @workflow_vars);
   }
 
@@ -148,16 +149,8 @@ sub summary {
 
   return if ($total == $passed && !$aggregate->has_problems);
 
-  # Create/Truncate the output file
-  {
-    open(my $fd, '>', $ENV{GITHUB_STEP_SUMMARY})
-      or die "Unable to open " . $ENV{GITHUB_STEP_SUMMARY} . ": $!"
-      if $RUNNING_IN_GHA;
-  }
-
   $self->_output("\n= GitHub Actions Report =\n");
 
-
   # First print a mark at the beginning of the files reporting errors with a
   # link to the workflow run for the full report.
   #
@@ -201,7 +194,7 @@ sub _dump_test_parser {
   $self->_output($_->as_gha_summary_for($test)) for (@error_groups);
 
   # Skip if not running in GitHub Actions
-  return unless $RUNNING_IN_GHA;
+  return if !($RUNNING_IN_GHA && !$GHA_SKIP_SUMMARY);
 
   # Write full report on GHA Step Summary [2]
   open(my $summary_fd, '>>', $ENV{GITHUB_STEP_SUMMARY}) or die "Unable to open " . $ENV{GITHUB_STEP_SUMMARY} . ": $!" if $RUNNING_IN_GHA;
